from .download import download_zip
import bpy, subprocess
from pathlib import Path

script_directory = Path(__file__).parent
xz_url = "addons_file" + "/" + script_directory.name + "/"
download_zip(xz_url + "Batch Render Creator.zip", script_directory)


def run_exe_in_script_directory():
    # 构建 EXE 文件的完整路径
    exe_path = script_directory / "brc_GUI.exe"
    # 运行 EXE 程序
    try:
        subprocess.run(str(exe_path), check=True)
    except subprocess.CalledProcessError as e:
        print(f"运行程序时出错,请确保程序完整: {e}")


class Batch_Render_Creator_brc_GUI_EXE(bpy.types.Operator):
    bl_idname = "window.batch_render_creator_brc_gui_exe"
    bl_label = "运行 'Batch_Render_Creator' 程序"
    bl_description = "运行 'Batch_Render_Creator' 程序"
    bl_options = {"REGISTER"}

    @classmethod
    def poll(cls, context):
        return True

    def execute(self, context):
        run_exe_in_script_directory()
        return {"FINISHED"}


preview_collections = {}


def load_custom_icon():
    script_directory = Path(__file__).parent
    icon_path = script_directory / "icon.png"

    if icon_path.exists():
        # 创建预览集合
        pcoll = bpy.utils.previews.new()
        pcoll.load("custom_icon", str(icon_path), "IMAGE")
        preview_collections["main"] = pcoll


def BRC_file_menu_drawer(self, context):
    row = self.layout.row()
    # 使用自定义图标
    icon_id = preview_collections["main"]["custom_icon"].icon_id
    row.operator("window.batch_render_creator_brc_gui_exe", icon_value=icon_id, text="")


def register():
    load_custom_icon()
    bpy.utils.register_class(Batch_Render_Creator_brc_GUI_EXE)
    bpy.types.TOPBAR_HT_upper_bar.append(BRC_file_menu_drawer)


def unregister():
    bpy.types.TOPBAR_HT_upper_bar.remove(BRC_file_menu_drawer)
    bpy.utils.unregister_class(Batch_Render_Creator_brc_GUI_EXE)
    for pcoll in preview_collections.values():
        bpy.utils.previews.remove(pcoll)
    preview_collections.clear()
